summaryrefslogtreecommitdiff
path: root/framework/inc/services/pluginframe.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'framework/inc/services/pluginframe.hxx')
-rw-r--r--framework/inc/services/pluginframe.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/inc/services/pluginframe.hxx b/framework/inc/services/pluginframe.hxx
index 555cc19718c5..3673d6df1dcf 100644
--- a/framework/inc/services/pluginframe.hxx
+++ b/framework/inc/services/pluginframe.hxx
@@ -80,7 +80,7 @@ namespace framework{
class PlugInFrame : public css::lang::XInitialization ,
public css::mozilla::XPluginInstance ,
public css::frame::XDispatchResultListener , // => XEVENTLISTENER
- public Frame // Order of baseclasses is neccessary for right initialization!
+ public Frame // Order of baseclasses is necessary for right initialization!
{
//-------------------------------------------------------------------------------------------------------------
// public methods
@@ -268,7 +268,7 @@ class PlugInFrame : public css::lang::XInitialization ,
sal_Bool m_bILoad ; /// PlugInFrame has a valid loader which load the document and wait for finished/cancelled
sal_Bool m_bIHaveDocument ; /// We have a document loaded successful.
css::uno::Reference< css::frame::XDispatchProvider > m_xPlugInDispatcher ; /// Dispatcher to forward dispatches to browser
- static sal_Bool m_bRemoteFactoriesExist ; /// indicates, if remote factories was already registered (neccessary one times only!)
+ static sal_Bool m_bRemoteFactoriesExist ; /// indicates, if remote factories was already registered (necessary one times only!)
SvtCommandOptions m_aCommandOptions ; /// ref counted class to support disabling commands defined by configuration file
}; // class PlugInFrame